Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(81)

Unified Diff: chrome/browser/sync/glue/sync_backend_registrar.h

Issue 7655055: [Sync] Make BackendMigrator not wait for full sync cycles (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Address more comments Created 9 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/glue/sync_backend_registrar.h
diff --git a/chrome/browser/sync/glue/sync_backend_registrar.h b/chrome/browser/sync/glue/sync_backend_registrar.h
index 56e02a9e127401e38d91d1b2a1ac3ecf89009e0d..6f9bd03b7a98a83c5bc5c18d7bece50fe577a416 100644
--- a/chrome/browser/sync/glue/sync_backend_registrar.h
+++ b/chrome/browser/sync/glue/sync_backend_registrar.h
@@ -33,9 +33,11 @@ class UIModelWorker;
class SyncBackendRegistrar : public ModelSafeWorkerRegistrar {
public:
// |initial_types| contains the initial set of types to sync
// (initially put in the passive group). Does not take ownership of
// |profile| or |sync_loop|. Must be created on the UI thread.
SyncBackendRegistrar(const syncable::ModelTypeSet& initial_types,
+ const std::string& name,
Profile* profile,
MessageLoop* sync_loop);
@@ -108,6 +110,9 @@ class SyncBackendRegistrar : public ModelSafeWorkerRegistrar {
bool IsCurrentThreadSafeForModel(
syncable::ModelType model_type) const;
+ // Name used for debugging.
+ const std::string name_;
+
Profile* const profile_;
MessageLoop* const sync_loop_;
« no previous file with comments | « chrome/browser/sync/glue/sync_backend_host_unittest.cc ('k') | chrome/browser/sync/glue/sync_backend_registrar.cc » ('j') | no next file with comments »
@@ -33,9 +33,11 @@ class UIModelWorker;
public:
// |initial_types| contains the initial set of types to sync
- // (initially put in the passive group). Does not take ownership of
- // |profile| or |sync_loop|. Must be created on the UI thread.
+ // (initially put in the passive group). |name| is used for
+ // debugging. Does not take ownership of |profile| or |sync_loop|.
+ // Must be created on the UI thread.
SyncBackendRegistrar(const syncable::ModelTypeSet& initial_types,

Powered by Google App Engine
This is Rietveld 408576698